#[sourcegen]Expand description
Does nothing (returns item as-is). Needed to remove the attribute that is handled by source generator.
#[sourcegen]Does nothing (returns item as-is). Needed to remove the attribute that is handled by source generator.